pub enum TryInsertError<'a, K1: 'a, K2: 'a, V: 'a> {
Occupied(OccupiedError<'a, K1, K2, V>),
Insert(InsertError<K1, K2, V>),
}Expand description
The error returned by try_insert method when the keys already exist
and point to the same value (look at OccupiedError) or there is no way to distinguish how
given value with key #1 and key #2 should be inserted. For more information about error kinds
look at OccupiedError, InsertError structures and ErrorKind enum.
Depending of error kind, this enum can contain:
- When there is
TryInsertError::Occupiedvariant, it contains the occupied entry, and the value that was not inserted (throughOccupiedErrorstructure). - When there is
TryInsertError::Insertvariant, it contains theErrorKindenum, the provided keys and value that were not inserted (throughInsertErrorstructure).
Variants
Occupied(OccupiedError<'a, K1, K2, V>)
The error kind returned by try_insert when the keys already
exist and point to the same value. Contains the OccupiedError structure.
Insert(InsertError<K1, K2, V>)
The error kind returned by try_insert method when there is no
way to distinguish how given value with key #1 and key #2 should be inserted. For more
information about error kinds look at InsertError structure and ErrorKind enum.
Contains the InsertError structure.